@@ -40,10 +40,10 @@ def ineichen(apparent_zenith, airmass_absolute, linke_turbidity,
     linke_turbidity : numeric
         Linke Turbidity.
 
-    altitude : numeric
+    altitude : numeric, default 0
         Altitude above sea level in meters.
 
-    dni_extra : numeric
+    dni_extra : numeric, default 1364
         Extraterrestrial irradiance. The units of ``dni_extra``
         determine the units of the output.
 
@@ -164,10 +164,10 @@ def lookup_linke_turbidity(time, latitude, longitude, filepath=None,
 
     longitude : float
 
-    filepath : string
+    filepath : None or string, default None
         The path to the ``.mat`` file.
 
-    interp_turbidity : bool
+    interp_turbidity : bool, default True
         If ``True``, interpolates the monthly Linke turbidity values
         found in ``LinkeTurbidities.mat`` to daily values.
 
@@ -196,8 +196,8 @@ def lookup_linke_turbidity(time, latitude, longitude, filepath=None,
     try:
         import scipy.io
     except ImportError:
-        raise ImportError('The Linke turbidity lookup table requires scipy. ' +
-                          'You can still use clearsky.ineichen if you ' +
+        raise ImportError('The Linke turbidity lookup table requires scipy. '
+                          'You can still use clearsky.ineichen if you '
                           'supply your own turbidities.')
 
     if filepath is None:
@@ -214,54 +214,95 @@ def lookup_linke_turbidity(time, latitude, longitude, filepath=None,
         np.around(_linearly_scale(longitude, -180, 180, 0, 4320))
         .astype(np.int64))
 
-    g = linke_turbidity_table[latitude_index][longitude_index]
+    lts = linke_turbidity_table[latitude_index][longitude_index]
 
     if interp_turbidity:
-        # Data covers 1 year. Assume that data corresponds to the value at the
-        # middle of each month. This means that we need to add previous Dec and
-        # next Jan to the array so that the interpolation will work for
-        # Jan 1 - Jan 15 and Dec 16 - Dec 31.
-        g2 = np.concatenate([[g[-1]], g, [g[0]]])
-        # Then we map the month value to the day of year value.
-        isleap = [calendar.isleap(t.year) for t in time]
-        if all(isleap):
-            days = _calendar_month_middles(2016)  # all years are leap
-        elif not any(isleap):
-            days = _calendar_month_middles(2015)  # none of the years are leap
-        else:
-            days = None  # some of the years are leap years and some are not
-        if days is None:
-            # Loop over different years, might be slow for large timeserires
-            linke_turbidity = pd.Series([
-                np.interp(t.dayofyear, _calendar_month_middles(t.year), g2)
-                for t in time
-            ], index=time)
-        else:
-            linke_turbidity = pd.Series(np.interp(time.dayofyear, days, g2),
-                                        index=time)
+        linke_turbidity = _interpolate_turbidity(lts, time)
     else:
-        linke_turbidity = pd.DataFrame(time.month, index=time)
-        # apply monthly data
-        linke_turbidity = linke_turbidity.apply(lambda x: g[x[0]-1], axis=1)
+        months = time.month - 1
+        linke_turbidity = pd.Series(lts[months], index=time)
 
     linke_turbidity /= 20.
 
     return linke_turbidity
 
 
+def _is_leap_year(year):
+    """Determine if a year is leap year.
+
+    Parameters
+    ----------
+    year : numeric
+
+    Returns
+    -------
+    isleap : array of bools
+    """
+    isleap = ((np.mod(year, 4) == 0) &
+              ((np.mod(year, 100) != 0) | (np.mod(year, 400) == 0)))
+    return isleap
+
+
+def _interpolate_turbidity(lts, time):
+    """
+    Interpolated monthly Linke turbidity onto daily values.
+
+    Parameters
+    ----------
+    lts : np.array
+        Monthly Linke turbidity values.
+    time : pd.DatetimeIndex
+        Times to be interpolated onto.
+
+    Returns
+    -------
+    linke_turbidity : pd.Series
+        The interpolated turbidity.
+    """
+    # Data covers 1 year. Assume that data corresponds to the value at the
+    # middle of each month. This means that we need to add previous Dec and
+    # next Jan to the array so that the interpolation will work for
+    # Jan 1 - Jan 15 and Dec 16 - Dec 31.
+    lts_concat = np.concatenate([[lts[-1]], lts, [lts[0]]])
+
+    # handle leap years
+    try:
+        isleap = time.is_leap_year
+    except AttributeError:
+        year = time.year
+        isleap = _is_leap_year(year)
+
+    dayofyear = time.dayofyear
+    days_leap = _calendar_month_middles(2016)
+    days_no_leap = _calendar_month_middles(2015)
+
+    # Then we map the month value to the day of year value.
+    # Do it for both leap and non-leap years.
+    lt_leap = np.interp(dayofyear, days_leap, lts_concat)
+    lt_no_leap = np.interp(dayofyear, days_no_leap, lts_concat)
+    linke_turbidity = np.where(isleap, lt_leap, lt_no_leap)
+
+    linke_turbidity = pd.Series(linke_turbidity, index=time)
+
+    return linke_turbidity
+
+
 def _calendar_month_middles(year):
-    """list of middle day of each month, used by Linke turbidity lookup"""
+    """List of middle day of each month, used by Linke turbidity lookup"""
     # remove mdays[0] since January starts at mdays[1]
-    # make local copy of mdays since we need to change February for leap years
+    # make local copy of mdays since we need to change
+    # February for leap years
     mdays = np.array(calendar.mdays[1:])
     ydays = 365
     # handle leap years
     if calendar.isleap(year):
         mdays[1] = mdays[1] + 1
         ydays = 366
-    return np.concatenate([[-calendar.mdays[-1] / 2.0],  # Dec last year
-                           np.cumsum(mdays) - np.array(mdays) / 2.,  # this year
-                           [ydays + calendar.mdays[1] / 2.0]])  # Jan next year
+    middles = np.concatenate(
+        [[-calendar.mdays[-1] / 2.0],  # Dec last year
+         np.cumsum(mdays) - np.array(mdays) / 2.,  # this year
+         [ydays + calendar.mdays[1] / 2.0]])  # Jan next year
+    return middles
 
 
 def _linearly_scale(inputmatrix, inputmin, inputmax, outputmin, outputmax):
@@ -294,9 +335,9 @@ def haurwitz(apparent_zenith):
 
     Implements the Haurwitz clear sky model for global horizontal
     irradiance (GHI) as presented in [1, 2]. A report on clear
-    sky models found the Haurwitz model to have the best performance of
-    models which require only zenith angle [3]. Extreme care should
-    be taken in the interpretation of this result!
+    sky models found the Haurwitz model to have the best performance
+    in terms of average monthly error among models which require only
+    zenith angle [3].
 
     Parameters
     ----------
@@ -306,7 +347,7 @@ def haurwitz(apparent_zenith):
 
     Returns
     -------
-    pd.Series
+    pd.DataFrame
     The modeled global horizonal irradiance in W/m^2 provided
     by the Haurwitz clear-sky model.
 
@@ -326,13 +367,14 @@ def haurwitz(apparent_zenith):
      Laboratories, SAND2012-2389, 2012.
     '''
 
-    cos_zenith = tools.cosd(apparent_zenith)
+    cos_zenith = tools.cosd(apparent_zenith.values)
+    clearsky_ghi = np.zeros_like(apparent_zenith.values)
+    clearsky_ghi[cos_zenith>0] = 1098.0 * cos_zenith[cos_zenith>0] * \
+                                    np.exp(-0.059/cos_zenith[cos_zenith>0])
 
-    clearsky_ghi = 1098.0 * cos_zenith * np.exp(-0.059/cos_zenith)
-
-    clearsky_ghi[clearsky_ghi < 0] = 0
-
-    df_out = pd.DataFrame({'ghi': clearsky_ghi})
+    df_out = pd.DataFrame(index=apparent_zenith.index,
+                          data=clearsky_ghi,
+                          columns=['ghi'])
 
     return df_out
 
@@ -352,21 +394,21 @@ def simplified_solis(apparent_elevation, aod700=0.1, precipitable_water=1.,
     apparent_elevation : numeric
         The apparent elevation of the sun above the horizon (deg).
 
-    aod700 : numeric
+    aod700 : numeric, default 0.1
         The aerosol optical depth at 700 nm (unitless).
         Algorithm derived for values between 0 and 0.45.
 
-    precipitable_water : numeric
+    precipitable_water : numeric, default 1.0
         The precipitable water of the atmosphere (cm).
         Algorithm derived for values between 0.2 and 10 cm.
         Values less than 0.2 will be assumed to be equal to 0.2.
 
-    pressure : numeric
+    pressure : numeric, default 101325.0
         The atmospheric pressure (Pascals).
         Algorithm derived for altitudes between sea level and 7000 m,
         or 101325 and 41000 Pascals.
 
-    dni_extra : numeric
+    dni_extra : numeric, default 1364.0
         Extraterrestrial irradiance. The units of ``dni_extra``
         determine the units of the output.
 
@@ -411,7 +453,7 @@ def simplified_solis(apparent_elevation, aod700=0.1, precipitable_water=1.,
     g = _calc_g(w, aod700)
 
     taud = _calc_taud(w, aod700, p)
-    d = _calc_d(w, aod700, p)
+    d = _calc_d(aod700, p)
 
     # this prevents the creation of nans at night instead of 0s
     # it's also friendly to scalar and series inputs
@@ -525,7 +567,7 @@ def _calc_taud(w, aod700, p):
     return taud
 
 
-def _calc_d(w, aod700, p):
+def _calc_d(aod700, p):
     """Calculate the d coefficient."""
 
     p0 = 101325.
@@ -569,29 +611,29 @@ def detect_clearsky(measured, clearsky, times, window_length,
     window_length : int
         Length of sliding time window in minutes. Must be greater than 2
         periods.
-    mean_diff : float
+    mean_diff : float, default 75
         Threshold value for agreement between mean values of measured
         and clearsky in each interval, see Eq. 6 in [1].
-    max_diff : float
+    max_diff : float, default 75
         Threshold value for agreement between maxima of measured and
         clearsky values in each interval, see Eq. 7 in [1].
-    lower_line_length : float
+    lower_line_length : float, default -5
         Lower limit of line length criterion from Eq. 8 in [1].
         Criterion satisfied when
         lower_line_length < line length difference < upper_line_length
-    upper_line_length : float
+    upper_line_length : float, default 10
         Upper limit of line length criterion from Eq. 8 in [1].
-    var_diff : float
+    var_diff : float, default 0.005
         Threshold value in Hz for the agreement between normalized
         standard deviations of rate of change in irradiance, see Eqs. 9
         through 11 in [1].
-    slope_dev : float
+    slope_dev : float, default 8
         Threshold value for agreement between the largest magnitude of
         change in successive values, see Eqs. 12 through 14 in [1].
-    max_iterations : int
+    max_iterations : int, default 20
         Maximum number of times to apply a different scaling factor to
         the clearsky and redetermine clear_samples. Must be 1 or larger.
-    return_components : bool
+    return_components : bool, default False
         Controls if additional output should be returned. See below.
 
     Returns
