@@ -56,48 +56,51 @@ class PVSystem(object):
 
     Parameters
     ----------
-    surface_tilt: float or array-like
-        Tilt angle of the module surface.
-        Up=0, horizon=90.
+    surface_tilt: float or array-like, default 0
+        Surface tilt angles in decimal degrees.
+        The tilt angle is defined as degrees from horizontal
+        (e.g. surface facing up = 0, surface facing horizon = 90)
 
-    surface_azimuth: float or array-like
+    surface_azimuth: float or array-like, default 180
         Azimuth angle of the module surface.
         North=0, East=90, South=180, West=270.
 
-    albedo : None, float
+    albedo : None or float, default None
         The ground albedo. If ``None``, will attempt to use
         ``surface_type`` and ``irradiance.SURFACE_ALBEDOS``
         to lookup albedo.
 
-    surface_type : None, string
+    surface_type : None or string, default None
         The ground surface type. See ``irradiance.SURFACE_ALBEDOS``
         for valid values.
 
-    module : None, string
+    module : None or string, default None
         The model name of the modules.
         May be used to look up the module_parameters dictionary
         via some other method.
 
-    module_parameters : None, dict or Series
+    module_parameters : None, dict or Series, default None
         Module parameters as defined by the SAPM, CEC, or other.
 
-    modules_per_string: int or float
+    modules_per_string: int or float, default 1
         See system topology discussion above.
 
-    strings_per_inverter: int or float
+    strings_per_inverter: int or float, default 1
         See system topology discussion above.
 
-    inverter : None, string
+    inverter : None or string, default None
         The model name of the inverters.
         May be used to look up the inverter_parameters dictionary
         via some other method.
 
-    inverter_parameters : None, dict or Series
+    inverter_parameters : None, dict or Series, default None
         Inverter parameters as defined by the SAPM, CEC, or other.
 
-    racking_model : None or string
+    racking_model : None or string, default 'open_rack_cell_glassback'
         Used for cell and module temperature calculations.
 
+    name : None or string, default None
+
     **kwargs
         Arbitrary keyword arguments.
         Included for compatibility, but not used.
@@ -149,14 +152,11 @@ class PVSystem(object):
 
         self.racking_model = racking_model
 
-        # needed for tying together Location and PVSystem in LocalizedPVSystem
-        super(PVSystem, self).__init__(**kwargs)
-
     def __repr__(self):
         attrs = ['name', 'surface_tilt', 'surface_azimuth', 'module',
                  'inverter', 'albedo', 'racking_model']
         return ('PVSystem: \n  ' + '\n  '.join(
-            (attr + ': ' + str(getattr(self, attr)) for attr in attrs)))
+            ('{}: {}'.format(attr, getattr(self, attr)) for attr in attrs)))
 
     def get_aoi(self, solar_zenith, solar_azimuth):
         """Get the angle of incidence on the system.
@@ -199,11 +199,11 @@ class PVSystem(object):
             Global horizontal irradiance
         dhi : float or Series
             Diffuse horizontal irradiance
-        dni_extra : float or Series
+        dni_extra : None, float or Series, default None
             Extraterrestrial direct normal irradiance
-        airmass : float or Series
+        airmass : None, float or Series, default None
             Airmass
-        model : String
+        model : String, default 'haydavies'
             Irradiance model.
 
         **kwargs
@@ -409,7 +409,7 @@ class PVSystem(object):
         aoi : numeric
             Angle of incidence in degrees.
 
-        reference_irradiance : numeric
+        reference_irradiance : numeric, default 1000
             Reference irradiance by which to divide the input irradiance.
 
         Returns
@@ -540,9 +540,9 @@ class PVSystem(object):
 
         Parameters
         ----------
-        location : None or Location
-        latitude : None or float
-        longitude : None or float
+        location : None or Location, default None
+        latitude : None or float, default None
+        longitude : None or float, default None
         **kwargs : see Location
 
         Returns
@@ -584,15 +584,15 @@ class LocalizedPVSystem(PVSystem, Location):
                           list(loc_dict.items()) +
                           list(kwargs.items()))
 
-        super(LocalizedPVSystem, self).__init__(**new_kwargs)
+        PVSystem.__init__(self, **new_kwargs)
+        Location.__init__(self, **new_kwargs)
 
     def __repr__(self):
-        attrs = [
-            'name', 'latitude', 'longitude', 'altitude', 'tz', 'surface_tilt',
-            'surface_azimuth', 'module', 'inverter', 'albedo', 'racking_model'
-                 ]
+        attrs = ['name', 'latitude', 'longitude', 'altitude', 'tz',
+                 'surface_tilt', 'surface_azimuth', 'module', 'inverter',
+                 'albedo', 'racking_model']
         return ('LocalizedPVSystem: \n  ' + '\n  '.join(
-            (attr + ': ' + str(getattr(self, attr)) for attr in attrs)))
+            ('{}: {}'.format(attr, getattr(self, attr)) for attr in attrs)))
 
 
 def systemdef(meta, surface_tilt, surface_azimuth, albedo, modules_per_string,
@@ -699,9 +699,9 @@ def ashraeiam(aoi, b=0.05):
     ----------
     aoi : numeric
         The angle of incidence between the module normal vector and the
-        sun-beam vector in degrees.
+        sun-beam vector in degrees. Angles of nan will result in nan.
 
-    b : float
+    b : float, default 0.05
         A parameter to adjust the modifier as a function of angle of
         incidence. Typical values are on the order of 0.05 [3].
 
@@ -711,7 +711,7 @@ def ashraeiam(aoi, b=0.05):
         The incident angle modifier calculated as 1-b*(sec(aoi)-1) as
         described in [2,3].
 
-        Returns nan for all abs(aoi) >= 90 and for all IAM values that
+        Returns zeros for all abs(aoi) >= 90 and for all IAM values that
         would be less than 0.
 
     References
@@ -734,7 +734,7 @@ def ashraeiam(aoi, b=0.05):
 
     iam = 1 - b*((1/np.cos(np.radians(aoi)) - 1))
 
-    iam = np.where(np.abs(aoi) >= 90, np.nan, iam)
+    iam = np.where(np.abs(aoi) >= 90, 0, iam)
     iam = np.maximum(0, iam)
 
     if isinstance(iam, pd.Series):
@@ -763,22 +763,23 @@ def physicaliam(aoi, n=1.526, K=4., L=0.002):
     ----------
     aoi : numeric
         The angle of incidence between the module normal vector and the
-        sun-beam vector in degrees.
+        sun-beam vector in degrees. Angles of 0 are replaced with 1e-06
+        to ensure non-nan results. Angles of nan will result in nan.
 
-    n : numeric
+    n : numeric, default 1.526
         The effective index of refraction (unitless). Reference [1]
         indicates that a value of 1.526 is acceptable for glass. n must
         be a numeric scalar or vector with all values >=0. If n is a
         vector, it must be the same size as all other input vectors.
 
-    K : numeric
+    K : numeric, default 4.0
         The glazing extinction coefficient in units of 1/meters.
         Reference [1] indicates that a value of  4 is reasonable for
         "water white" glass. K must be a numeric scalar or vector with
         all values >=0. If K is a vector, it must be the same size as
         all other input vectors.
 
-    L : numeric
+    L : numeric, default 0.002
         The glazing thickness in units of meters. Reference [1]
         indicates that 0.002 meters (2 mm) is reasonable for most
         glass-covered PV panels. L must be a numeric scalar or vector
@@ -813,27 +814,40 @@ def physicaliam(aoi, n=1.526, K=4., L=0.002):
     spa
     ashraeiam
     '''
-    thetar_deg = tools.asind(1.0 / n*(tools.sind(aoi)))
-
-    tau = (np.exp(- 1.0 * (K*L / tools.cosd(thetar_deg))) *
-           ((1 - 0.5*((((tools.sind(thetar_deg - aoi)) ** 2) /
-            ((tools.sind(thetar_deg + aoi)) ** 2) +
-            ((tools.tand(thetar_deg - aoi)) ** 2) /
-            ((tools.tand(thetar_deg + aoi)) ** 2))))))
-
     zeroang = 1e-06
 
-    thetar_deg0 = tools.asind(1.0 / n*(tools.sind(zeroang)))
+    aoi = np.where(aoi == 0, zeroang, aoi)
 
-    tau0 = (np.exp(- 1.0 * (K*L / tools.cosd(thetar_deg0))) *
-            ((1 - 0.5*((((tools.sind(thetar_deg0 - zeroang)) ** 2) /
-             ((tools.sind(thetar_deg0 + zeroang)) ** 2) +
-             ((tools.tand(thetar_deg0 - zeroang)) ** 2) /
-             ((tools.tand(thetar_deg0 + zeroang)) ** 2))))))
+    # angle of reflection
+    thetar_deg = tools.asind(1.0 / n*(tools.sind(aoi)))
 
-    iam = tau / tau0
+    # reflectance and transmittance for normal incidence light
+    rho_zero = ((1-n) / (1+n)) ** 2
+    tau_zero = np.exp(-K*L)
 
-    iam = np.where((np.abs(aoi) >= 90) | (iam < 0), np.nan, iam)
+    # reflectance for parallel and perpendicular polarized light
+    rho_para = (tools.tand(thetar_deg - aoi) /
+                tools.tand(thetar_deg + aoi)) ** 2
+    rho_perp = (tools.sind(thetar_deg - aoi) /
+                tools.sind(thetar_deg + aoi)) ** 2
+
+    # transmittance for non-normal light
+    tau = np.exp(-K*L / tools.cosd(thetar_deg))
+
+    # iam is ratio of non-normal to normal incidence transmitted light
+    # after deducting the reflected portion of each
+    iam = ((1 - (rho_para + rho_perp) / 2) / (1 - rho_zero) * tau / tau_zero)
+
+    # angles near zero produce nan, but iam is defined as one
+    small_angle = 1e-06
+    iam = np.where(np.abs(aoi) < small_angle, 1.0, iam)
+
+    # angles at 90 degrees can produce tiny negative values, which should be zero
+    # this is a result of calculation precision rather than the physical model
+    iam = np.where(iam < 0, 0, iam)
+
+    # for light coming from behind the plane, none can enter the module
+    iam = np.where(aoi > 90, 0, iam)
 
     if isinstance(aoi, pd.Series):
         iam = pd.Series(iam, index=aoi.index)
@@ -1071,7 +1085,7 @@ def retrieve_sam(name=None, path=None):
 
     Parameters
     ----------
-    name : None or string
+    name : None or string, default None
         Name can be one of:
 
         * 'CECMod' - returns the CEC module database
@@ -1082,7 +1096,7 @@ def retrieve_sam(name=None, path=None):
         * 'SandiaMod' - returns the Sandia Module database
         * 'ADRInverter' - returns the ADR Inverter database
 
-    path : None or string
+    path : None or string, default None
         Path to the SAM file. May also be a URL.
 
     If both name and path are None, a dialogue will open allowing the
@@ -1345,7 +1359,7 @@ def sapm_celltemp(poa_global, wind_speed, temp_air,
     temp_air : float or Series
         Ambient dry bulb temperature in degrees C.
 
-    model : string, list, or dict
+    model : string, list, or dict, default 'open_rack_cell_glassback'
         Model to be used.
 
         If string, can be:
@@ -1464,14 +1478,14 @@ def sapm_aoi_loss(aoi, module, upper=None):
     ----------
     aoi : numeric
         Angle of incidence in degrees. Negative input angles will return
-        nan values.
+        zeros.
 
     module : dict-like
         A dict, Series, or DataFrame defining the SAPM performance
         parameters. See the :py:func:`sapm` notes section for more
         details.
 
-    upper : None or float
+    upper : None or float, default None
         Upper limit on the results.
 
     Returns
@@ -1506,7 +1520,7 @@ def sapm_aoi_loss(aoi, module, upper=None):
 
     aoi_loss = np.polyval(aoi_coeff, aoi)
     aoi_loss = np.clip(aoi_loss, 0, upper)
-    aoi_loss = np.where(aoi < 0, np.nan, aoi_loss)
+    aoi_loss = np.where(aoi < 0, 0, aoi_loss)
 
     if isinstance(aoi, pd.Series):
         aoi_loss = pd.Series(aoi_loss, aoi.index)
@@ -1539,7 +1553,7 @@ def sapm_effective_irradiance(poa_direct, poa_diffuse, airmass_absolute, aoi,
         parameters. See the :py:func:`sapm` notes section for more
         details.
 
-    reference_irradiance : numeric
+    reference_irradiance : numeric, default 1000
         Reference irradiance by which to divide the input irradiance.
 
     Returns
@@ -1584,18 +1598,22 @@ def singlediode(photocurrent, saturation_current, resistance_series,
     photocurrent : numeric
         Light-generated current (photocurrent) in amperes under desired
         IV curve conditions. Often abbreviated ``I_L``.
+        0 <= photocurrent
 
     saturation_current : numeric
         Diode saturation current in amperes under desired IV curve
         conditions. Often abbreviated ``I_0``.
+        0 < saturation_current
 
     resistance_series : numeric
         Series resistance in ohms under desired IV curve conditions.
         Often abbreviated ``Rs``.
+        0 <= resistance_series < numpy.inf
 
     resistance_shunt : numeric
         Shunt resistance in ohms under desired IV curve conditions.
         Often abbreviated ``Rsh``.
+        0 < resistance_shunt <= numpy.inf
 
     nNsVth : numeric
         The product of three components. 1) The usual diode ideal factor
@@ -1605,8 +1623,9 @@ def singlediode(photocurrent, saturation_current, resistance_series,
         ``k*temp_cell/q``, where k is Boltzmann's constant (J/K),
         temp_cell is the temperature of the p-n junction in Kelvin, and
         q is the charge of an electron (coulombs).
+        0 < nNsVth
 
-    ivcurve_pnts : None or int
+    ivcurve_pnts : None or int, default None
         Number of points in the desired IV curve. If None or 0, no
         IV curves will be produced.
 
@@ -1660,12 +1679,12 @@ def singlediode(photocurrent, saturation_current, resistance_series,
     calcparams_desoto
     '''
 
-    # Find short circuit current using Lambert W
-    i_sc = i_from_v(resistance_shunt, resistance_series, nNsVth, 0.01,
+    # Compute short circuit current
+    i_sc = i_from_v(resistance_shunt, resistance_series, nNsVth, 0.,
                     saturation_current, photocurrent)
 
-    # Find open circuit voltage using Lambert W
-    v_oc = v_from_i(resistance_shunt, resistance_series, nNsVth, 0.0,
+    # Compute open circuit voltage
+    v_oc = v_from_i(resistance_shunt, resistance_series, nNsVth, 0.,
                     saturation_current, photocurrent)
 
     params = {'r_sh': resistance_shunt,
@@ -1674,7 +1693,7 @@ def singlediode(photocurrent, saturation_current, resistance_series,
               'i_0': saturation_current,
               'i_l': photocurrent}
 
-    p_mp, v_mp = _golden_sect_DataFrame(params, 0, v_oc*1.14, _pwr_optfcn)
+    p_mp, v_mp = _golden_sect_DataFrame(params, 0., v_oc * 1.14, _pwr_optfcn)
 
     # Invert the Power-Current curve. Find the current where the inverted power
     # is minimized. This is i_mp. Start the optimization at v_oc/2
@@ -1682,11 +1701,11 @@ def singlediode(photocurrent, saturation_current, resistance_series,
                     saturation_current, photocurrent)
 
     # Find Ix and Ixx using Lambert W
-    i_x = i_from_v(resistance_shunt, resistance_series, nNsVth,
-                   0.5*v_oc, saturation_current, photocurrent)
+    i_x = i_from_v(resistance_shunt, resistance_series, nNsVth, 0.5 * v_oc,
+                   saturation_current, photocurrent)
 
     i_xx = i_from_v(resistance_shunt, resistance_series, nNsVth,
-                    0.5*(v_oc+v_mp), saturation_current, photocurrent)
+                    0.5 * (v_oc + v_mp), saturation_current, photocurrent)
 
     out = OrderedDict()
     out['i_sc'] = i_sc
@@ -1701,9 +1720,10 @@ def singlediode(photocurrent, saturation_current, resistance_series,
     if ivcurve_pnts:
         ivcurve_v = (np.asarray(v_oc)[..., np.newaxis] *
                      np.linspace(0, 1, ivcurve_pnts))
-        ivcurve_i = i_from_v(
-            resistance_shunt, resistance_series, nNsVth, ivcurve_v.T,
-            saturation_current, photocurrent).T
+
+        ivcurve_i = i_from_v(resistance_shunt, resistance_series, nNsVth,
+                             ivcurve_v.T, saturation_current, photocurrent).T
+
         out['v'] = ivcurve_v
         out['i'] = ivcurve_i
 
@@ -1790,25 +1810,38 @@ def _pwr_optfcn(df, loc):
     Function to find power from ``i_from_v``.
     '''
 
-    I = i_from_v(df['r_sh'], df['r_s'], df['nNsVth'],
-                 df[loc], df['i_0'], df['i_l'])
-    return I*df[loc]
+    I = i_from_v(df['r_sh'], df['r_s'], df['nNsVth'], df[loc], df['i_0'],
+                 df['i_l'])
+
+    return I * df[loc]
 
 
 def v_from_i(resistance_shunt, resistance_series, nNsVth, current,
              saturation_current, photocurrent):
     '''
-    Calculates voltage from current per Eq 3 Jain and Kapoor 2004 [1].
+    Device voltage at the given device current for the single diode model.
+
+    Uses the single diode model (SDM) as described in, e.g.,
+     Jain and Kapoor 2004 [1].
+    The solution is per Eq 3 of [1] except when resistance_shunt=numpy.inf,
+     in which case the explict solution for voltage is used.
+    Ideal device parameters are specified by resistance_shunt=np.inf and
+     resistance_series=0.
+    Inputs to this function can include scalars and pandas.Series, but it is
+     the caller's responsibility to ensure that the arguments are all float64
+     and within the proper ranges.
 
     Parameters
     ----------
     resistance_shunt : numeric
         Shunt resistance in ohms under desired IV curve conditions.
         Often abbreviated ``Rsh``.
+        0 < resistance_shunt <= numpy.inf
 
     resistance_series : numeric
         Series resistance in ohms under desired IV curve conditions.
         Often abbreviated ``Rs``.
+        0 <= resistance_series < numpy.inf
 
     nNsVth : numeric
         The product of three components. 1) The usual diode ideal factor
@@ -1818,6 +1851,7 @@ def v_from_i(resistance_shunt, resistance_series, nNsVth, current,
         ``k*temp_cell/q``, where k is Boltzmann's constant (J/K),
         temp_cell is the temperature of the p-n junction in Kelvin, and
         q is the charge of an electron (coulombs).
+        0 < nNsVth
 
     current : numeric
         The current in amperes under desired IV curve conditions.
@@ -1825,14 +1859,16 @@ def v_from_i(resistance_shunt, resistance_series, nNsVth, current,
     saturation_current : numeric
         Diode saturation current in amperes under desired IV curve
         conditions. Often abbreviated ``I_0``.
+        0 < saturation_current
 
     photocurrent : numeric
         Light-generated current (photocurrent) in amperes under desired
         IV curve conditions. Often abbreviated ``I_L``.
+        0 <= photocurrent
 
     Returns
     -------
-    current : np.array
+    current : np.ndarray or scalar
 
     References
     ----------
@@ -1845,51 +1881,105 @@ def v_from_i(resistance_shunt, resistance_series, nNsVth, current,
     except ImportError:
         raise ImportError('This function requires scipy')
 
-    Rsh = resistance_shunt
-    Rs = resistance_series
-    I0 = saturation_current
-    IL = photocurrent
-    I = current
+    # Record if inputs were all scalar
+    output_is_scalar = all(map(np.isscalar,
+                               [resistance_shunt, resistance_series, nNsVth,
+                                current, saturation_current, photocurrent]))
 
-    argW = I0 * Rsh / nNsVth * np.exp(Rsh * (-I + IL + I0) / nNsVth)
-    lambertwterm = lambertw(argW).real
+    # This transforms Gsh=1/Rsh, including ideal Rsh=np.inf into Gsh=0., which
+    #  is generally more numerically stable
+    conductance_shunt = 1./resistance_shunt
 
-    # Calculate using log(argW) in case argW is really big
-    logargW = (np.log(I0) + np.log(Rsh) - np.log(nNsVth) +
-               Rsh * (-I + IL + I0) / nNsVth)
+    # Ensure that we are working with read-only views of numpy arrays
+    # Turns Series into arrays so that we don't have to worry about
+    #  multidimensional broadcasting failing
+    Gsh, Rs, a, I, I0, IL = \
+        np.broadcast_arrays(conductance_shunt, resistance_series, nNsVth,
+                            current, saturation_current, photocurrent)
 
-    # Three iterations of Newton-Raphson method to solve
-    # w+log(w)=logargW. The initial guess is w=logargW. Where direct
-    # evaluation (above) results in NaN from overflow, 3 iterations
-    # of Newton's method gives approximately 8 digits of precision.
-    w = logargW
-    for i in range(0, 3):
-        w = w * (1 - np.log(w) + logargW) / (1 + w)
-    lambertwterm_log = w
+    # Intitalize output V (I might not be float64)
+    V = np.full_like(I, np.nan, dtype=np.float64)
 
-    lambertwterm = np.where(np.isfinite(lambertwterm), lambertwterm,
-                            lambertwterm_log)
+    # Determine indices where 0 < Gsh requires implicit model solution
+    idx_p = 0. < Gsh
 
-    # Eqn. 3 in Jain and Kapoor, 2004
-    V = -I*(Rs + Rsh) + IL*Rsh - nNsVth*lambertwterm + I0*Rsh
+    # Determine indices where 0 = Gsh allows explicit model solution
+    idx_z = 0. == Gsh
 
-    return V
+    # Explicit solutions where Gsh=0
+    if np.any(idx_z):
+        V[idx_z] = a[idx_z]*np.log1p((IL[idx_z] - I[idx_z])/I0[idx_z]) - \
+            I[idx_z]*Rs[idx_z]
+
+    # Only compute using LambertW if there are cases with Gsh>0
+    if np.any(idx_p):
+        # LambertW argument, cannot be float128, may overflow to np.inf
+        argW = I0[idx_p] / (Gsh[idx_p]*a[idx_p]) * \
+            np.exp((-I[idx_p] + IL[idx_p] + I0[idx_p]) /
+                   (Gsh[idx_p]*a[idx_p]))
+
+        # lambertw typically returns complex value with zero imaginary part
+        # may overflow to np.inf
+        lambertwterm = lambertw(argW).real
+
+        # Record indices where lambertw input overflowed output
+        idx_inf = np.logical_not(np.isfinite(lambertwterm))
+
+        # Only re-compute LambertW if it overflowed
+        if np.any(idx_inf):
+            # Calculate using log(argW) in case argW is really big
+            logargW = (np.log(I0[idx_p]) - np.log(Gsh[idx_p]) -
+                       np.log(a[idx_p]) +
+                       (-I[idx_p] + IL[idx_p] + I0[idx_p]) /
+                       (Gsh[idx_p] * a[idx_p]))[idx_inf]
+
+            # Three iterations of Newton-Raphson method to solve
+            #  w+log(w)=logargW. The initial guess is w=logargW. Where direct
+            #  evaluation (above) results in NaN from overflow, 3 iterations
+            #  of Newton's method gives approximately 8 digits of precision.
+            w = logargW
+            for _ in range(0, 3):
+                w = w * (1. - np.log(w) + logargW) / (1. + w)
+            lambertwterm[idx_inf] = w
+
+        # Eqn. 3 in Jain and Kapoor, 2004
+        #  V = -I*(Rs + Rsh) + IL*Rsh - a*lambertwterm + I0*Rsh
+        # Recast in terms of Gsh=1/Rsh for better numerical stability.
+        V[idx_p] = (IL[idx_p] + I0[idx_p] - I[idx_p])/Gsh[idx_p] - \
+            I[idx_p]*Rs[idx_p] - a[idx_p]*lambertwterm
+
+    if output_is_scalar:
+        return np.asscalar(V)
+    else:
+        return V
 
 
 def i_from_v(resistance_shunt, resistance_series, nNsVth, voltage,
              saturation_current, photocurrent):
     '''
-    Calculates current from voltage per Eq 2 Jain and Kapoor 2004 [1].
+    Device current at the given device voltage for the single diode model.
+
+    Uses the single diode model (SDM) as described in, e.g.,
+     Jain and Kapoor 2004 [1].
+    The solution is per Eq 2 of [1] except when resistance_series=0,
+     in which case the explict solution for current is used.
+    Ideal device parameters are specified by resistance_shunt=np.inf and
+     resistance_series=0.
+    Inputs to this function can include scalars and pandas.Series, but it is
+     the caller's responsibility to ensure that the arguments are all float64
+     and within the proper ranges.
 
     Parameters
     ----------
     resistance_shunt : numeric
         Shunt resistance in ohms under desired IV curve conditions.
         Often abbreviated ``Rsh``.
+        0 < resistance_shunt <= numpy.inf
 
     resistance_series : numeric
         Series resistance in ohms under desired IV curve conditions.
         Often abbreviated ``Rs``.
+        0 <= resistance_series < numpy.inf
 
     nNsVth : numeric
         The product of three components. 1) The usual diode ideal factor
@@ -1899,6 +1989,7 @@ def i_from_v(resistance_shunt, resistance_series, nNsVth, voltage,
         ``k*temp_cell/q``, where k is Boltzmann's constant (J/K),
         temp_cell is the temperature of the p-n junction in Kelvin, and
         q is the charge of an electron (coulombs).
+        0 < nNsVth
 
     voltage : numeric
         The voltage in Volts under desired IV curve conditions.
@@ -1906,14 +1997,16 @@ def i_from_v(resistance_shunt, resistance_series, nNsVth, voltage,
     saturation_current : numeric
         Diode saturation current in amperes under desired IV curve
         conditions. Often abbreviated ``I_0``.
+        0 < saturation_current
 
     photocurrent : numeric
         Light-generated current (photocurrent) in amperes under desired
         IV curve conditions. Often abbreviated ``I_L``.
+        0 <= photocurrent
 
     Returns
     -------
-    current : np.array
+    current : np.ndarray or scalar
 
     References
     ----------
@@ -1926,23 +2019,58 @@ def i_from_v(resistance_shunt, resistance_series, nNsVth, voltage,
     except ImportError:
         raise ImportError('This function requires scipy')
 
-    # asarray turns Series into arrays so that we don't have to worry
-    # about multidimensional broadcasting failing
-    Rsh = np.asarray(resistance_shunt)
-    Rs = np.asarray(resistance_series)
-    I0 = np.asarray(saturation_current)
-    IL = np.asarray(photocurrent)
-    V = np.asarray(voltage)
+    # Record if inputs were all scalar
+    output_is_scalar = all(map(np.isscalar,
+                               [resistance_shunt, resistance_series, nNsVth,
+                                voltage, saturation_current, photocurrent]))
 
-    argW = (Rs*I0*Rsh *
-            np.exp(Rsh*(Rs*(IL+I0)+V) / (nNsVth*(Rs+Rsh))) /
-            (nNsVth*(Rs + Rsh)))
-    lambertwterm = lambertw(argW).real
+    # This transforms Gsh=1/Rsh, including ideal Rsh=np.inf into Gsh=0., which
+    #  is generally more numerically stable
+    conductance_shunt = 1./resistance_shunt
 
-    # Eqn. 4 in Jain and Kapoor, 2004
-    I = -V/(Rs + Rsh) - (nNsVth/Rs)*lambertwterm + Rsh*(IL + I0)/(Rs + Rsh)
+    # Ensure that we are working with read-only views of numpy arrays
+    # Turns Series into arrays so that we don't have to worry about
+    #  multidimensional broadcasting failing
+    Gsh, Rs, a, V, I0, IL = \
+        np.broadcast_arrays(conductance_shunt, resistance_series, nNsVth,
+                            voltage, saturation_current, photocurrent)
 
-    return I
+    # Intitalize output I (V might not be float64)
+    I = np.full_like(V, np.nan, dtype=np.float64)
+
+    # Determine indices where 0 < Rs requires implicit model solution
+    idx_p = 0. < Rs
+
+    # Determine indices where 0 = Rs allows explicit model solution
+    idx_z = 0. == Rs
+
+    # Explicit solutions where Rs=0
+    if np.any(idx_z):
+        I[idx_z] = IL[idx_z] - I0[idx_z]*np.expm1(V[idx_z]/a[idx_z]) - \
+            Gsh[idx_z]*V[idx_z]
+
+    # Only compute using LambertW if there are cases with Rs>0
+    # Does NOT handle possibility of overflow, github issue 298
+    if np.any(idx_p):
+        # LambertW argument, cannot be float128, may overflow to np.inf
+        argW = Rs[idx_p]*I0[idx_p]/(a[idx_p]*(Rs[idx_p]*Gsh[idx_p] + 1.)) * \
+            np.exp((Rs[idx_p]*(IL[idx_p] + I0[idx_p]) + V[idx_p]) /
+                   (a[idx_p]*(Rs[idx_p]*Gsh[idx_p] + 1.)))
+
+        # lambertw typically returns complex value with zero imaginary part
+        # may overflow to np.inf
+        lambertwterm = lambertw(argW).real
+
+        # Eqn. 2 in Jain and Kapoor, 2004
+        #  I = -V/(Rs + Rsh) - (a/Rs)*lambertwterm + Rsh*(IL + I0)/(Rs + Rsh)
+        # Recast in terms of Gsh=1/Rsh for better numerical stability.
+        I[idx_p] = (IL[idx_p] + I0[idx_p] - V[idx_p]*Gsh[idx_p]) / \
+            (Rs[idx_p]*Gsh[idx_p] + 1.) - (a[idx_p]/Rs[idx_p])*lambertwterm
+
+    if output_is_scalar:
+        return np.asscalar(I)
+    else:
+        return I
 
 
 def snlinverter(v_dc, p_dc, inverter):
@@ -2082,9 +2210,9 @@ def adrinverter(v_dc, p_dc, inverter, vtol=0.10):
         supplied data table using retrievesam.
         See Notes for required keys.
 
-    vtol : numeric
-        A unit-less fraction that determines how far the efficiency model is 
-        allowed to extrapolate beyond the inverter's normal input voltage 
+    vtol : numeric, default 0.1
+        A unit-less fraction that determines how far the efficiency model is
+        allowed to extrapolate beyond the inverter's normal input voltage
         operating range. 0.0 <= vtol <= 1.0
 
     Returns
@@ -2108,21 +2236,21 @@ def adrinverter(v_dc, p_dc, inverter, vtol=0.10):
     Column    Description
     =======   ============================================================
     p_nom     The nominal power value used to normalize all power values,
-              typically the DC power needed to produce maximum AC power 
+              typically the DC power needed to produce maximum AC power
               output, (W).
 
-    v_nom     The nominal DC voltage value used to normalize DC voltage 
-              values, typically the level at which the highest efficiency 
+    v_nom     The nominal DC voltage value used to normalize DC voltage
+              values, typically the level at which the highest efficiency
               is achieved, (V).
 
-    pac_max   The maximum AC output power value, used to clip the output 
+    pac_max   The maximum AC output power value, used to clip the output
               if needed, (W).
 
     ce_list   This is a list of 9 coefficients that capture the influence
               of input voltage and power on inverter losses, and thereby
               efficiency.
 
-    p_nt      ac-power consumed by inverter at night (night tare) to 
+    p_nt      ac-power consumed by inverter at night (night tare) to
               maintain circuitry required to sense PV array voltage, (W).
     =======   ============================================================
 
@@ -2181,9 +2309,9 @@ def scale_voltage_current_power(data, voltage=1, current=1):
     data: DataFrame
         Must contain columns `'v_mp', 'v_oc', 'i_mp' ,'i_x', 'i_xx',
         'i_sc', 'p_mp'`.
-    voltage: numeric
+    voltage: numeric, default 1
         The amount by which to multiply the voltages.
-    current: numeric
+    current: numeric, default 1
         The amount by which to multiply the currents.
 
     Returns
@@ -2227,7 +2355,7 @@ def pvwatts_dc(g_poa_effective, temp_cell, pdc0, gamma_pdc, temp_ref=25.):
     gamma_pdc: numeric
         The temperature coefficient in units of 1/C. Typically -0.002 to
         -0.005 per degree C.
-    temp_ref: numeric
+    temp_ref: numeric, default 25.0
         Cell reference temperature. PVWatts defines it to be 25 C and
         is included here for flexibility.
 
@@ -2264,17 +2392,17 @@ def pvwatts_losses(soiling=2, shading=3, snow=0, mismatch=2, wiring=2,
 
     Parameters
     ----------
-    soiling: numeric
-    shading: numeric
-    snow: numeric
-    mismatch: numeric
-    wiring: numeric
-    connections: numeric
-    lid: numeric
+    soiling: numeric, default 2
+    shading: numeric, default 3
+    snow: numeric, default 0
+    mismatch: numeric, default 2
+    wiring: numeric, default 2
+    connections: numeric, default 0.5
+    lid: numeric, default 1.5
         Light induced degradation
-    nameplate_rating: numeric
-    age: numeric
-    availability: numeric
+    nameplate_rating: numeric, default 1
+    age: numeric, default 0
+    availability: numeric, default 3
 
     Returns
     -------
@@ -2322,9 +2450,9 @@ def pvwatts_ac(pdc, pdc0, eta_inv_nom=0.96, eta_inv_ref=0.9637):
         DC power.
     pdc0: numeric
         Nameplate DC rating.
-    eta_inv_nom: numeric
+    eta_inv_nom: numeric, default 0.96
         Nominal inverter efficiency.
-    eta_inv_ref: numeric
+    eta_inv_ref: numeric, default 0.9637
         Reference inverter efficiency. PVWatts defines it to be 0.9637
         and is included here for flexibility.
 
