@@ -952,7 +952,6 @@ def solar_position_loop(unixtime, loc_args, out):
         x = xterm(u, lat, elev)
         y = yterm(u, lat, elev)
         delta_alpha = parallax_sun_right_ascension(x, xi, H, delta)
-        alpha_prime = topocentric_sun_right_ascension(alpha, delta_alpha)
         delta_prime = topocentric_sun_declination(delta, x, y, xi, delta_alpha,
                                                   H)
         H_prime = topocentric_local_hour_angle(H, delta_alpha)
@@ -1064,7 +1063,6 @@ def solar_position_numpy(unixtime, lat, lon, elev, pressure, temp, delta_t,
     x = xterm(u, lat, elev)
     y = yterm(u, lat, elev)
     delta_alpha = parallax_sun_right_ascension(x, xi, H, delta)
-    alpha_prime = topocentric_sun_right_ascension(alpha, delta_alpha)
     delta_prime = topocentric_sun_declination(delta, x, y, xi, delta_alpha, H)
     H_prime = topocentric_local_hour_angle(H, delta_alpha)
     e0 = topocentric_elevation_angle_without_atmosphere(lat, delta_prime,
@@ -1119,13 +1117,13 @@ def solar_position(unixtime, lat, lon, elev, pressure, temp, delta_t,
     atmos_refrac : float, optional
         The approximate atmospheric refraction (in degrees)
         at sunrise and sunset.
-    numthreads: int, optional
+    numthreads: int, optional, default 8
         Number of threads to use for computation if numba>=0.17
         is installed.
-    sst : bool
+    sst : bool, default False
         If True, return only data needed for sunrise, sunset, and transit
         calculations.
-    esd : bool
+    esd : bool, default False
         If True, return only Earth-Sun distance in AU
 
     Returns
